@@ -1,7 +1,7 @@
 from abc import ABC, abstractmethod
-from contextlib import ContextDecorator, ExitStack, contextmanager, suppress
+from contextlib import ExitStack, contextmanager, suppress
 from dataclasses import dataclass, field
-from typing import ContextManager
+from typing import ContextManager, Self
 from weakref import WeakSet
 
 __all__ = ("Event", "EventChannel", "EventListener")
@@ -24,7 +24,7 @@ class EventChannel:
     __listeners: WeakSet[EventListener] = field(default_factory=WeakSet, init=False)
 
     @contextmanager
-    def dispatch(self, event: Event) -> ContextManager | ContextDecorator:
+    def dispatch(self, event: Event):
         with ExitStack() as stack:
             for listener in tuple(self.__listeners):
                 context_manager = listener.on_event(event)
@@ -36,11 +36,11 @@ class EventChannel:
 
             yield
 
-    def add_listener(self, listener: EventListener):
+    def add_listener(self, listener: EventListener) -> Self:
         self.__listeners.add(listener)
         return self
 
-    def remove_listener(self, listener: EventListener):
+    def remove_listener(self, listener: EventListener) -> Self:
         with suppress(KeyError):
             self.__listeners.remove(listener)
 
